@@ -19,7 +19,7 @@ use tokio::{
     time::sleep,
 };
 
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread", worker_threads = 4)]
 async fn test_latency() {
     setup(6666).await;
     sleep(Duration::from_secs(1)).await;
@@ -87,8 +87,6 @@ impl WorldSession<MyWorld> for MyWorldSession {
     async fn on_message(_world_session: &Arc<Self>, _world: &'static MyWorld, _packet: Packet) {}
 
     async fn on_close(_world_session: &Arc<Self>, _world: &'static MyWorld) {}
-
-    async fn on_dos_attack(_world_session: &Arc<Self>, _world: &'static MyWorld, _cmd: u16) {}
 }
 
 #[world_time]
