@@ -18,7 +18,7 @@ use tokio::{
     time::sleep,
 };
 
-#[tokio::test]
+#[tokio::test(flavor = "multi_thread", worker_threads = 4)]
 async fn test_write_packet() {
     setup(6666).await;
     sleep(Duration::from_secs(1)).await;
@@ -76,8 +76,6 @@ impl WorldSession<MyWorld> for MyWorldSession {
         }))
     }
 
-    async fn on_dos_attack(_world_session: &Arc<Self>, _world: &'static MyWorld, _cmd: u16) {}
-
     fn socket_tools(&self) -> &SocketTools {
         &self.socket_tools
     }
